.. _user_guide:

User Guide
==========

The User Guide includes detailed individual subjects covering how to setup and use Buildcat effectively.

.. nbgallery::
    :name: user-guide
    :glob:

    user-guide/*
